@@ -1,23 +1,32 @@
 bar.err <-
-function(x,variation=c("SE","SD","range"),horiz=FALSE, bar=TRUE,...) {
+function(x,variation=c("SE","SD","range","IQR"),horiz=FALSE, bar=TRUE,...) {
 variation<-match.arg(variation)
 y<-x[,1]
 names(y)<-rownames(x)
 if( variation=="SE" ) {
-names(x)-> nombre
-if(sum(nombre=="SE")==0) std.err<-x$"std"/sqrt(x$"r")
-else std.err<-x$"SE"
+if( "std"%in%names(x) & variation != "IQR") {
+std.err<-x$"std"/sqrt(x$"r")
 nivel0<-y-std.err
 nivel1<-y+std.err
 }
+else return("For variation use IQR or range")
+}
 if( variation=="SD" ) {
+if("std" %in% names(x)){
 nivel0<-y-x$"std"
 nivel1<-y+x$"std"
 }
+else return("For variation use IQR or range")
+}
 if( variation=="range" ) {
 nivel0<-x$"Min"
 nivel1<-x$"Max"
 }
+if( variation=="IQR") {
+nivel0<-x$"Q25"
+nivel1<-x$"Q75"
+}
+
 n<-length(y)
 if (bar) {
 indice<-barplot(y,horiz=horiz, ...)
@@ -40,5 +49,5 @@ text( cex=1,indice[i],nivel0[i],"---")
 text( cex=1,indice[i],nivel1[i],"---")
 }
 }
-invisible(list(index=indice,means=y))
+invisible(list(x=indice,height=y))
 }
