@@ -1,4 +1,4 @@
-`kendall` <-
+kendall <-
 function(data1,data2) {
 n<-length(data1)
 n2<-0;n1<-0;is<-0
@@ -31,4 +31,3 @@ z<-is/sqrt(vark(data1,data2))
 prob<- 2*pnorm(-abs(z))
 return(list(stat=z,tau=tau,pvalue=prob))
 }
-
